@@ -12,6 +12,7 @@ import time
 import logging
 from pyftdi.spi import SpiIOError
 from ..core.sensor import SPISensor
+from ..core.error import Error
 from pyftdi.ftdi import FtdiError
 
 
@@ -118,7 +119,8 @@ class MAX31865(SPISensor):
 
     def get_data(self):
         """
-        Fetch data from sensor and write to default data layout defined in the base class
+        Fetch data from sensor and write to
+        default data layout defined in the base class
         """
         data = self.default_data()
 
@@ -126,15 +128,20 @@ class MAX31865(SPISensor):
             self.setup()
         except SpiIOError:
             self.disconnected_ftdi = True
-        else:
-            data["values"] = {}
-            data["values"]["temperature"] = {
-                "value": self.temperature,
-                "unit": self._units["temperature"],
-            }
-            data["error"] = False
-        finally:
-            return data
+            return Error().read(self)
+
+        T = self.temperature
+        if T is None:
+            return Error().read(self)
+
+        data["values"] = {}
+        data["values"]["temperature"] = {
+            "value": T,
+            "unit": self._units["temperature"],
+        }
+        data["error"] = False
+
+        return data
 
     @property
     def bias(self):
@@ -260,4 +267,4 @@ class MAX31865(SPISensor):
         temp -= 2.8183e-8 * rpoly
         rpoly *= raw_reading  # ^5
         temp += 1.5243e-10 * rpoly
-        return temp
+        return round(temp, 3)
