@@ -21,6 +21,7 @@ class S8000(UARTSensor):
     }
     _log = None
     _max_waiting_time = 0.5  # [s]
+    __max_attempts = 2
 
     _COMMANDS = {
         # Register map definition   Address[dec] Register config.
@@ -163,6 +164,9 @@ class S8000(UARTSensor):
         self.data = self.default_data()
         dewpoint = self.HUMIDITY()
         T = self.AMBTEMP()
+        if T == 120:
+            T = None
+
         self.data["values"] = {}
         self.data["values"]["dewpoint"] = {
             "value": dewpoint,
@@ -178,8 +182,9 @@ class S8000(UARTSensor):
 
     @timeout_decorator.timeout(5, timeout_exception=StopIteration)
     def get_serial_number(self):
-        self.HUMIDITY
-        return self.get_ftdi_serial()
+        test = self.HUMIDITY()
+        if test is not None:
+            return self.get_ftdi_serial()
 
     def __str__(self):
         return f"S8000@{self.port}"
