@@ -18,8 +18,8 @@ except ImportError:
     import ustruct as struct
 
 
-class SFM3XXX(I2CSensor):
-    __name__ = "SFM3XXX"
+class SFM(I2CSensor):
+    __name__ = "SFM"
     _serial_mode = "I2C"
     _SENSOR_ADDRESS = 0x40
     _units = {
@@ -187,6 +187,9 @@ class SFM3XXX(I2CSensor):
             self.error = Error().read(self)
             return self.error
 
+class SFMXXX(SFM):
+    pass
+
+class SFM3XXX(SFM):
+    pass
 
-class SFMXXX(SFM3XXX):
-    __name__ = "SFMXXX"
