@@ -50,6 +50,7 @@ class SPS30(UARTSensor):
     __SERIAL_NUMBER = [0x03, 0x2B]  # Read serial number
     __PRODUCT_TYPE = [0x00, 0x7E]  # Get product type
     __DEVICE_INFORMATION = [0x00, 0xD0, 0x01]  # Get device information
+    __START_CLEANING = [0x00, 0x56, 0x00, 0xA9]
 
     def __init__(self, port, scan=False):
         self.port = port
@@ -183,6 +184,12 @@ class SPS30(UARTSensor):
         time.sleep(1.04)  # max sampling intervall according to datasheet
         return data
 
+    def clean(self):
+        self.txrx(self.__START_CLEANING, read=0)
+        self._log.error("Started fan cleaning.")
+        time.sleep(10)
+
+
     def read_values(self):
         raw = self.txrx(self.__READ_DATA, read=47)
         if raw is None:
